<?php

namespace Drupal\webform_telegram_notice\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure for telegram notice handler.
 */
class WebformTelegramNoticeConfigForm extends ConfigFormBase
{
  /**
   * @return string
   */
  public function getFormId(): string
  {
    return 'webform_telegram_notice_admin_settings';
  }

  /**
   * Gets the configuration names that will be editable.
   *
   * An array of configuration object names that are editable if called in
   * conjunction with the trait's config() method.
   *
   * @return array
   */
  protected function getEditableConfigNames(): array
  {
    return [
      'webform_telegram_notice.settings',
    ];
  }

  /**
   * @param array $form
   * @param FormStateInterface $form_state
   * @return array
   */
  public function buildForm(array $form, FormStateInterface $form_state): array
  {
    $config = $this->config('webform_telegram_notice.settings');

    $form['token'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API token'),
      '#description' => $this->t(''),
      '#default_value' => $config->get('token'),
    ];

    $form['id_chat'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Group ID'),
      '#description' => $this->t(''),
      '#default_value' => $config->get('id_chat'),
    ];

    $form['exception'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Exception fields'),
      '#description' => $this->t('Exclusion of webform fields from submission. Specify machine names separated by commas.'),
      '#default_value' => $config->get('exception'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state): void
  {
    if(empty($form_state->getValue('token'))) {
      $form_state->setErrorByName('reinstall', $this->t('API token required'));
    }

    if(empty($form_state->getValue('id_chat'))) {
      $form_state->setErrorByName('reinstall', $this->t('Group ID required'));
    }
  }

  /**
   * @param array $form
   * @param FormStateInterface $form_state
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void
  {
    try {
      $this->config('webform_telegram_notice.settings')
        ->set('id_chat', $form_state->getValue('id_chat'))
        ->set('token', $form_state->getValue('token'))
        ->set('exception', $form_state->getValue('exception'))
        ->save();
    }
    catch (\Exception $e) {
      $this->messenger()->addError($this->t(' Error: %error.', ['%error' => $e->getMessage()]));
    }
  }
}
